@@ -1,7 +1,10 @@
 class OrderStatus:
+    PENDING = 0
     PAYMENT_SUBMITTED = 1
     PAYMENT_RECEIVED = 2
     PROCESSING = 3
     PROCESSED = 4
     SHIPPED = 5
-    RECEIVED = 6
\ No newline at end of file
+    RECEIVED = 6
+    ON_HOLD = 7
+    CANCELLED = 8
\ No newline at end of file
